@@ -40,10 +40,7 @@ File::File(const QString& url)
     d->url = QFileInfo(url).canonicalFilePath();
 }
 
-File::~File()
-{
-    delete d;
-}
+File::~File() = default;
 
 const File& File::operator=(const File& f)
 {
@@ -58,11 +55,7 @@ QString File::path() const
     return d->url;
 }
 
-#if BALOO_CORE_BUILD_DEPRECATED_SINCE(5, 91)
-KFileMetaData::PropertyMap File::properties() const
-#else
 KFileMetaData::PropertyMultiMap File::properties() const
-#endif
 {
     return d->propertyMap;
 }
